@@ -37,12 +37,19 @@ try
 
     fork.run();
 }
-catch (Errno const &err)
+catch (exception const &err)
 {
-    cout << err.why() << endl;
+    cout << err.what() << endl;
     return 1;
 }
 catch (Options::ExitStatus status)
 {
     return status;
 }
+catch (int x)
+{
+    return ArgConfig::instance().option("hv") ? 0 : x;
+}
+
+
+
